.. Ansible Style Guide documentation master file, created by
   sphinx-quickstart on Mon May 11 12:41:35 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _style_guide:

*******************
Ansible Style Guide
*******************

Welcome to the Ansible Style Guide
==================================

Follow these guidelines to create clear, concise, useful community contributions and documentation. This guide helps us make the content on ansible.com consistent.

.. toctree::
  :maxdepth: 1

  basic_rules
  voice_style
  trademarks
  grammar_punctuation
  spelling_word_choice
  resources


.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
